@@ -93,11 +93,11 @@ test_that("function compute branch lenght when tree is supplied", {
 
   require("SESraster")
   # tests
-  expect(rast.pe.ses(x = x, tree = tree,
+  expect_no_error(rast.pe.ses(x = x, tree = tree,
                      spat_alg = "bootspat_str",
                      metric = "pe",
                      spat_alg_args = list(rprob = NULL,
                                           rich = NULL,
                                           fr_prob = NULL),
-                     aleats = 5), ok = T)
+                     aleats = 5))
 })
